<?php

class ExpayEventPay extends ExpayBaseEvent
{
    public function handle($event)
    {
        if (!$this->isHashValid($event)) {
            $this->sendResponse(401, 'Invalid hash');

            return false;
        }

        $order = new Order($event['order']);
        if (!$this->isOrderValid($order)) {
            $this->sendResponse(475, 'Payment with the specified parameters can not be processed');

            return false;
        }

        if (!$this->amountMatching($order, $event)) {
            $this->sendResponse(475, 'Payment with the specified parameters can not be processed');

            return false;
        }

        if ($this->isOrderCanceled($order)) {
            $this->sendResponse(475, 'Payment with the specified parameters can not be processed');

            return false;
        }

        if (!$this->isPaymentStatusSuccess($event)) {
            $message = 'Expay Webhooks: status of order#' . $event['order'] . 'change to "Canceled"';
            $this->expay_logger->add($message);

            $this->payment_order->updateStateToBeCanceled($order);

            $this->sendResponse(475, 'Payment with the specified parameters can not be processed');

            return false;
        }

        if ($this->isOrderPaid($order)) {
            $this->sendResponse(205, 'Payment success');

            return true;
        }

        $this->payment_order->updateStateToBeSuccess($order);

        $message = 'Expay Webhooks: status of order#' . $order->id . 'change to "Payment accepted"';
        $this->expay_logger->add($message);

        $this->sendResponse(205, 'Payment success');
        return true;
    }

    /** Check the Payment status in Expay Server */
    private function isPaymentStatusSuccess($event)
    {
        $status = $this->provider->getPaymentStatus($event['id']);
        if ($status != 203 && $status != 205) {
            $message = 'Expay Webhooks: The status of order #' . $event['order'] . ' in Expay server is not success.';
            $this->expay_logger->add($message);

            return false;
        }
        return true;
    }
}
